pub struct Picked {
pub entity: EntityRef,
pub detail: Option<String>,
pub tone: Tone,
}Expand description
An entity a Reference holds, and what the editor found it to be.
Fields
entity: EntityRefdetail: Option<String>What it is used as, or why it cannot be.
tone: ToneTrait Implementations
impl StructuralPartialEq for Picked